@@ -25,16 +25,16 @@ class MaskedImaging(imaging.MaskedImaging, abstract.AbstractLensMasked):
         preload_sparse_grids_of_planes=None,
     ):
         """
-        The lens dataset is the collection of data (image, noise map, PSF), a mask, grid, convolver \
+        The lens dataset is the collection of data (image, noise-map, PSF), a mask, grid, convolver \
         and other utilities that are used for modeling and fitting an image of a strong lens.
 
-        Whilst the image, noise map, etc. are loaded in 2D, the lens dataset creates reduced 1D arrays of each \
+        Whilst the image, noise-map, etc. are loaded in 2D, the lens dataset creates reduced 1D arrays of each \
         for lens calculations.
 
         Parameters
         ----------
         imaging: im.Imaging
-            The imaging data all in 2D (the image, noise map, PSF, etc.)
+            The imaging data all in 2D (the image, noise-map, PSF, etc.)
         mask: msk.Mask
             The 2D mask that is applied to the image.
         sub_size : int
