@@ -1,18 +1,17 @@
 import os
 
+from autoconf import conf
 import pytest
 from matplotlib import pyplot
 
-import autofit as af
-
 
 @pytest.fixture(name="general_config", autouse=True)
 def make_general_config():
     directory = os.path.dirname(os.path.realpath(__file__))
     config_path = f"{directory}/integration/config"
     plotting_config_path = f"{config_path}/plotting/"
-    af.conf.instance.general = af.conf.NamedConfig(plotting_config_path + "general.ini")
-    af.conf.instance.config_path = config_path
+    conf.instance.general = conf.NamedConfig(plotting_config_path + "general.ini")
+    conf.instance.config_path = config_path
 
 
 class PlotPatch:
