@@ -1,12 +1,12 @@
 from autolens.fit.plotters import masked_imaging_fit_plotters
-from test_autolens.simulate.imaging import simulate_util
+from test_autolens.simulate.imaging import instrument_util
 
 # In this tutorial, we'll introduce a new pixelization, called an adaptive-pixelization. This pixelization doesn't use
 # uniform grid of rectangular pixels, but instead uses ir'Voronoi' pixels. So, why would we want to do that?
 # Lets take another look at the rectangular grid, and think about its weakness.
 
 # Lets quickly remind ourselves of the image, and the 3.0" circular mask we'll use to mask it.
-imaging = simulate_util.load_test_imaging(
+imaging = instrument_util.load_test_imaging(
     data_name="lens_light_dev_vaucouleurs", instrument="vro"
 )
 mask = al.Mask.elliptical(
