@@ -1,8 +1,8 @@
 import autolens as al
 
-from test_autolens.simulate.imaging import simulate_util
+from test_autolens.simulate.imaging import instrument_util
 
-imaging = simulate_util.load_test_imaging(
+imaging = instrument_util.load_test_imaging(
     data_name="lens_sie__source_smooth__offset_centre", instrument="vro"
 )
 
