@@ -5,13 +5,16 @@ import numpy as np
 
 repeats = 1
 
-total_visibilities = 1000000
-pixelization_shape_2d = (30, 30)
+kspace_shape = 512
+total_visibilities = kspace_shape ** 2
 
-real_space_shape_2d = (256, 256)
+real_space_shape = 256
+real_space_shape_2d = (real_space_shape, real_space_shape)
+real_space_pixels = real_space_shape_2d[0] * real_space_shape_2d[1]
 real_space_pixel_scales = 0.05
 real_space_sub_size = 1
 real_space_radius = 3.0
+pixelization_shape_2d = (30, 30)
 
 image_pixels = real_space_shape_2d[0] * real_space_shape_2d[1]
 source_pixels = pixelization_shape_2d[0] * pixelization_shape_2d[1]
@@ -32,7 +35,6 @@ print()
 # stop
 
 vis = np.random.uniform(low=-5.0, high=5.0, size=(total_visibilities, 2))
-
 visibilities = al.Visibilities.manual_1d(visibilities=vis)
 uv_wavelengths = np.ones(shape=(total_visibilities, 2))
 noise_map = al.Visibilities.ones(shape_1d=(total_visibilities,))
@@ -67,6 +69,16 @@ mask = al.Mask.circular(
     radius=real_space_radius,
 )
 
+mask = np.full(shape=(real_space_shape + 2, real_space_shape + 2), fill_value=False)
+mask[0, :] = True
+mask[:, 0] = True
+mask[-1, :] = True
+mask[:, -1] = True
+
+mask = al.Mask.manual(
+    mask=mask, pixel_scales=real_space_pixel_scales, sub_size=real_space_sub_size
+)
+
 masked_interferometer = al.MaskedInterferometer(
     interferometer=interferometer,
     real_space_mask=mask,
@@ -125,6 +137,8 @@ for i in range(repeats):
 diff = time.time() - start
 print("Time to compute transformed mapping matrices = {}".format(diff / repeats))
 
+stop
+
 start = time.time()
 for i in range(repeats):
     real_data_vector = al.util.inversion.data_vector_via_transformed_mapping_matrix_from(
@@ -214,7 +228,9 @@ print(
 
 start = time.time()
 for i in range(repeats):
-    al.fit(masked_dataset=masked_interferometer, tracer=tracer)
+    fit = al.FitInterferometer(
+        masked_interferometer=masked_interferometer, tracer=tracer
+    )
 diff = time.time() - start
 print("Time to perform complete fit = {}".format(diff / repeats))
 
